diff -Naur kaffe-1.0.6/configure.in kaffe-1.0.6.new/configure.in
--- kaffe-1.0.6/configure.in	Mon Jul 24 19:43:44 2000
+++ kaffe-1.0.6.new/configure.in	Wed May 23 08:11:35 2001
@@ -381,10 +381,21 @@
 dnl -------------------------------------------------------------------------
 
 AC_ARG_WITH(threads,[  --with-threads=SYSTEM   Define which threading system to use])
+dnl guerrini@cnisrl.it: On LynxOS jthreads are hopelessly unusable.
+dnl No problem: LynxOS supports pthreads.
+case "$Khost_os" in
+lynxos)	if test x"$with_threads" = x"unix-jthreads" ; then
+		AC_MSG_WARN([unix-jthreads won't work on LynxOS])
+	fi
+	AC_MSG_WARN([Assuming --with-threads=unix-pthreads])
+	with_threads=unix-pthreads
+	;;
+*)	if test x"$with_threads" = x"" ; then
+		with_threads=unix-jthreads
+	fi
+	;;
+esac
 AC_MSG_CHECKING(thread system)
-if test x"$with_threads" = x"" ; then
-	with_threads=unix-jthreads
-fi
 if test ! -d $srcdir/kaffe/kaffevm/systems/${with_threads} ; then
 	AC_MSG_ERROR(Configuration $Khost_cpu-$Khost_os does not support $with_threads threads)
 fi
@@ -583,6 +594,12 @@
 AC_CHECK_FUNC(gethostbyname)
 if test $ac_cv_func_gethostbyname = no; then
       AC_CHECK_LIBRARY(nsl, gethostbyname, NET_LIBS)
+      case "$Khost_os" in
+      lynxos)
+            if test $ac_cv_func_gethostbyname = no; then
+                  AC_CHECK_LIBRARY(bsd, gethostbyname, NET_LIBS)
+            fi
+      esac
 fi
 AC_CHECK_FUNC(connect)
 if test $ac_cv_func_connect = no; then
@@ -610,10 +627,12 @@
 
 dnl Check for thread libraries
 if test x$with_threads = xunix-pthreads ; then
+      if test x"$Khost_os" != x"lynxos"; then
 	AC_CHECK_LIBRARY(pthread,pthread_create,VM_LIBS)
 	if test $ac_cv_lib_pthread_pthread_create = no; then
 		AC_MSG_ERROR([Missing library libpthread, read FAQ/FAQ.pthreads])
 	fi
+      fi
 fi
 
 dnl Checks for libraries for X related libraries.
diff -Naur kaffe-1.0.6/include/system.h kaffe-1.0.6.new/include/system.h
--- kaffe-1.0.6/include/system.h	Fri Aug 13 17:57:29 1999
+++ kaffe-1.0.6.new/include/system.h	Wed May  9 14:12:28 2001
@@ -28,7 +28,7 @@
 #define	kaffe_specification_name	"Java Platform API Specification"
 #define	kaffe_class_version		"46.0"
 
-#if defined(unix) || defined(__unix__) || defined(__BEOS__) || defined(__NetBSD__)
+#if defined(unix) || defined(__unix__) || defined(__BEOS__) || defined(__NetBSD__) || defined(__Lynx__)
 #define	file_separator		"/"
 #define	path_separator		":"
 #define	line_separator		"\n"
diff -Naur kaffe-1.0.6/kaffe/kaffevm/jni.c kaffe-1.0.6.new/kaffe/kaffevm/jni.c
--- kaffe-1.0.6/kaffe/kaffevm/jni.c	Mon Jun 19 11:55:59 2000
+++ kaffe-1.0.6.new/kaffe/kaffevm/jni.c	Wed May  9 14:36:07 2001
@@ -49,6 +49,10 @@
 #include "feedback.h"
 #endif
 
+#ifdef __Lynx__
+extern void vfprintf();
+#endif
+
 /*
  * Define the version of JNI we support.
  */
diff -Naur kaffe-1.0.6/kaffe/kaffevm/systems/unix-pthreads/lock-impl.c kaffe-1.0.6.new/kaffe/kaffevm/systems/unix-pthreads/lock-impl.c
--- kaffe-1.0.6/kaffe/kaffevm/systems/unix-pthreads/lock-impl.c	Fri Dec 10 07:49:06 1999
+++ kaffe-1.0.6.new/kaffe/kaffevm/systems/unix-pthreads/lock-impl.c	Wed May 23 07:22:01 2001
@@ -40,11 +40,15 @@
 	cur->blockState &= ~BS_CV;
   }
   else {
-	/* timeout is in millisecs, timeval in microsecs, and timespec in nanosecs */
+/* timeout is in millisecs, timeval in microsecs, and timespec in nanosecs */
+#if defined(__Lynx__)
+	abst.tv_sec = (timeout / 1000);
+	abst.tv_nsec = (timeout % 1000) * 1000000;
+#else
 	gettimeofday( &now, 0);
 	abst.tv_sec = now.tv_sec + (timeout / 1000);
 	abst.tv_nsec = (now.tv_usec * 1000) + (timeout % 1000) * 1000000;
- 
+#endif 
 	cur->blockState |= BS_CV_TO;
 	stat = pthread_cond_timedwait( cv, mux, &abst);
 	cur->blockState &= ~BS_CV_TO;
diff -Naur kaffe-1.0.6/kaffe/kaffevm/systems/unix-pthreads/lock-impl.h kaffe-1.0.6.new/kaffe/kaffevm/systems/unix-pthreads/lock-impl.h
--- kaffe-1.0.6/kaffe/kaffevm/systems/unix-pthreads/lock-impl.h	Fri Dec 10 07:49:06 1999
+++ kaffe-1.0.6.new/kaffe/kaffevm/systems/unix-pthreads/lock-impl.h	Tue May 22 16:31:17 2001
@@ -47,6 +47,11 @@
    * by means of inheriting the highest priority of any thread who
    * requests the mutex
    */
+#if defined(__Lynx__)
+  pthread_mutexattr_create( &muxAttr);
+  pthread_mutex_init( lk, muxAttr);
+  pthread_mutexattr_delete( &muxAttr);
+#else
   pthread_mutexattr_init( &muxAttr);
 #if defined(_POSIX_THREAD_PROCESS_SHARED)
   pthread_mutexattr_setpshared( &muxAttr, PTHREAD_PROCESS_PRIVATE);
@@ -55,6 +60,7 @@
   pthread_mutexattr_setprotocol( &muxAttr, PTHREAD_PRIO_INHERIT);
 #endif
   pthread_mutex_init( lk, &muxAttr);
+#endif
 }
 
 static inline
@@ -93,11 +99,17 @@
   pthread_condattr_t    cvAttr;
 
   /* init a process private condvar */
+#if defined(__Lynx__)
+  pthread_condattr_create( &cvAttr);
+  pthread_cond_init( cv, cvAttr);
+  pthread_condattr_delete( &cvAttr);
+#else
   pthread_condattr_init( &cvAttr);
 #if defined(_POSIX_THREAD_PROCESS_SHARED)
   pthread_condattr_setpshared( &cvAttr, PTHREAD_PROCESS_PRIVATE);
 #endif
   pthread_cond_init( cv, &cvAttr);
+#endif
 }
 
 static inline
diff -Naur kaffe-1.0.6/kaffe/kaffevm/systems/unix-pthreads/thread-impl.c kaffe-1.0.6.new/kaffe/kaffevm/systems/unix-pthreads/thread-impl.c
--- kaffe-1.0.6/kaffe/kaffevm/systems/unix-pthreads/thread-impl.c	Fri Dec 10 07:49:06 1999
+++ kaffe-1.0.6.new/kaffe/kaffevm/systems/unix-pthreads/thread-impl.c	Tue May 22 17:56:43 2001
@@ -12,6 +12,11 @@
 #include <semaphore.h>
 #include <sched.h>
 
+#if defined(__Lynx__)
+#define jthread_enable_stop dummy_jthread_enable_stop
+#define jthread_disable_stop dummy_jthread_disable_stop
+#endif
+
 #include "config.h"
 #include "config-std.h"
 #include "config-signal.h"
@@ -57,7 +62,9 @@
  * typedefs & defines
  */
 
+#if !defined(__Lynx__)
 #include <bits/local_lim.h>
+#endif
 
 /*
  * This is the configurable section. Note that SCHED_FIFO is the only
@@ -179,6 +186,21 @@
 } while (0)
 
 
+#if defined(__Lynx__)
+#undef jthread_enable_stop
+void jthread_enable_stop(void) { }
+#undef jthread_disable_stop
+void jthread_disable_stop(void) { }
+
+nativeThread* my_pthread_getspecific(void)
+{
+int rv;
+void *v;
+
+	rv = pthread_getspecific(ntKey,&v);
+	return (nativeThread *)(rv ? NULL : v);
+}
+#endif
 /***********************************************************************
  * internal functions
  */
@@ -300,11 +322,21 @@
 
   sp.sched_priority = priorities[0];  /* looow */
 
+#if defined(__Lynx__)
+  pthread_attr_create( &attr);
+  pthread_attr_setprio( &attr, sp.sched_priority);
+#else
   pthread_attr_init( &attr);
   pthread_attr_setschedparam( &attr, &sp);
+#endif
   pthread_attr_setstacksize( &attr, 4096);
 
+#if defined(__Lynx__)
+  pthread_create( &deadlockWatchdog, attr, tWatchdogRun, 0);
+  pthread_attr_delete( &attr);
+#else
   pthread_create( &deadlockWatchdog, &attr, tWatchdogRun, 0);
+#endif
 }
 
 
@@ -379,7 +411,7 @@
   max = sched_get_priority_max( SCHEDULE_POLICY);
 
   d = max - min;
-  n = sizeof( priorities);
+  n = sizeof(priorities) / sizeof(priorities[0]);
   r = (float)d / (float)n;
 
   for ( i=0; i<n; i++ ) {
@@ -462,7 +494,11 @@
   nt = GET_CURRENT_THREAD( &nt );
 
   /* we can't use nt->attr, because it wasn't used to create this thread */
+#if defined(__Lynx__)
+  pthread_attr_create( &nt->attr);
+#else
   pthread_attr_init( &nt->attr);
+#endif
 
   nt->tid    = pthread_self();
   nt->thread = thread;
@@ -493,7 +529,12 @@
    */
   pthread_setspecific( ntKey, nt); 
   unhand(thread)->PrivateInfo = (struct Hkaffe_util_Ptr*)nt;
+#if defined(__Lynx__)
+  pthread_setcancel(CANCEL_ON);
+  pthread_setasynccancel(CANCEL_ON);
+#else
   pthread_setcanceltype( PTHREAD_CANCEL_ASYNCHRONOUS, &oldCancelType);
+#endif
   
   /* if we aren't the first one, we are in trouble */
   assert( activeThreads == 0);
@@ -523,7 +564,11 @@
   int		   iLockRoot;
 
   /* get the stack boundaries */
+#if defined(__Lynx__)
+  ss = pthread_attr_getstacksize( &cur->attr);
+#else
   pthread_attr_getstacksize( &cur->attr, &ss);
+#endif
 
 #if defined(STACK_GROWS_UP)
   cur->stackMin = &cur;
@@ -534,7 +579,12 @@
 #endif
 
   pthread_setspecific( ntKey, cur);
+#if defined(__Lynx__)
+  pthread_setcancel(CANCEL_ON);
+  pthread_setasynccancel(CANCEL_ON);
+#else
   pthread_setcanceltype( PTHREAD_CANCEL_ASYNCHRONOUS, &oldCancelType);
+#endif
 
   cur->tid = pthread_self();
 
@@ -666,7 +716,11 @@
 	nt->stackCur = 0;
 	unhand(thread)->PrivateInfo = (struct Hkaffe_util_Ptr*)nt;
 
+#if defined(__Lynx__)
+	pthread_setprio( nt->tid, sp.sched_priority);
+#else
 	pthread_setschedparam( nt->tid, SCHEDULE_POLICY, &sp);
+#endif
 
 	DBG( vm_thread, TMSG_SHORT( "create recycled ", nt));
 
@@ -685,9 +739,14 @@
 
 	nt = thread_malloc( sizeof(nativeThread) );
 
+#if defined(__Lynx__)
+	pthread_attr_create( &nt->attr);
+	pthread_attr_setprio( &nt->attr, sp.sched_priority);
+#else
 	pthread_attr_init( &nt->attr);
 	pthread_attr_setschedparam( &nt->attr, &sp);
 	pthread_attr_setschedpolicy( &nt->attr, SCHEDULE_POLICY);
+#endif
 	pthread_attr_setstacksize( &nt->attr, threadStackSize);
 
 	nt->thread       = thread;
@@ -719,7 +778,12 @@
 	 * we otherwise might have a invalid tid in the activeList. The new thread
 	 * in turn doesn't need the lock until it exits
 	 */
+#if defined(__Lynx__)
+	pthread_create( &nt->tid, nt->attr, tRun, nt);
+	pthread_attr_delete( &nt->attr);
+#else
 	pthread_create( &nt->tid, &nt->attr, tRun, nt);
+#endif
 
 	/* wait until the thread specific data has been set, and the new thread
 	 * is in a suspendable state */
@@ -743,7 +807,11 @@
 void
 tDispose ( nativeThread* nt )
 {
+#if defined(__Lynx__)
+  pthread_detach(&(nt->tid));
+#else
   pthread_detach( nt->tid);
+#endif
 
   sem_destroy( &nt->sem);
 
@@ -873,7 +941,11 @@
 
 	DBG( vm_thread, ("set priority: %p [tid: %d, java: %x) to %d (%d)\n",
 					 cur, cur->tid, cur->thread, prio, priorities[prio]));
+#if defined(__Lynx__)
+	pthread_setprio( cur->tid, sp.sched_priority);
+#else
 	pthread_setschedparam( cur->tid, SCHEDULE_POLICY, &sp);
+#endif
   }
 }            
 
diff -Naur kaffe-1.0.6/kaffe/kaffevm/systems/unix-pthreads/thread-internal.h kaffe-1.0.6.new/kaffe/kaffevm/systems/unix-pthreads/thread-internal.h
--- kaffe-1.0.6/kaffe/kaffevm/systems/unix-pthreads/thread-internal.h	Fri Dec 10 07:49:06 1999
+++ kaffe-1.0.6.new/kaffe/kaffevm/systems/unix-pthreads/thread-internal.h	Tue May 22 15:17:47 2001
@@ -71,8 +71,16 @@
  * This should really be as fast as possible (and a VM-public compile time
  * interface)
  */
-#define GET_CURRENT_THREAD(_stackadr) \
-  (nativeThread*) pthread_getspecific( ntKey)
+#if defined(__Lynx__)
+	extern nativeThread* my_pthread_getspecific(void);
+	#define _POSIX_THREAD_THREADS_MAX 128
+	#define pthread_key_create pthread_keycreate
+	#define GET_CURRENT_THREAD(_stackadr) \
+	  my_pthread_getspecific()
+#else
+	#define GET_CURRENT_THREAD(_stackadr) \
+	  (nativeThread*) pthread_getspecific( ntKey)
+#endif
 
 #define NATIVE_THREAD(_jthread) \
   ((nativeThread*) unhand(_jthread)->PrivateInfo)
diff -Naur kaffe-1.0.6/kaffe/kaffevm/utf8const.c kaffe-1.0.6.new/kaffe/kaffevm/utf8const.c
--- kaffe-1.0.6/kaffe/kaffevm/utf8const.c	Wed Jun 21 07:04:40 2000
+++ kaffe-1.0.6.new/kaffe/kaffevm/utf8const.c	Tue May 22 16:17:47 2001
@@ -22,6 +22,10 @@
 #include "stringSupport.h"
 #include "stats.h"
 
+#if defined(__Lynx__)
+#define DBGIF(x)
+#endif
+
 /* For kaffeh, don't use the hash table. Instead, just make these
    function calls into macros in such a way as to avoid compiler
    warnings.  Yuk! */
diff -Naur kaffe-1.0.6/libltdl/ltdl.c kaffe-1.0.6.new/libltdl/ltdl.c
--- kaffe-1.0.6/libltdl/ltdl.c	Tue Feb 15 23:18:09 2000
+++ kaffe-1.0.6.new/libltdl/ltdl.c	Wed May  9 13:47:29 2001
@@ -114,6 +114,8 @@
 static const char objdir[] = LTDL_OBJDIR;
 #ifdef	LTDL_SHLIB_EXT
 static const char shlib_ext[] = LTDL_SHLIB_EXT;
+#else
+static const char shlib_ext[] = "";
 #endif
 #ifdef	LTDL_SYSSEARCHPATH
 static const char sys_search_path[] = LTDL_SYSSEARCHPATH;
